==> camitk_3.2.2.orig.tar.gz: camitk-3.2.2-Source/sdk/actions/mesh/meshprocessing/InvertMesh.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#include "InvertMesh.h"

#include <QString>
#include <QMessageBox>
#include <QTextStream>
#include <Application.h>


#include <vtkPolyDataNormals.h>
#include <vtkSmartPointer.h>

using namespace camitk;


// --------------- Constructor -------------------
InvertMesh::InvertMesh(ActionExtension * extension) : Action(extension) {
    // Setting name, description and input component 
    setName("InvertMesh");
    setDescription("Invert the mesh faces");
    setComponent("MeshComponent");

    // Setting classification family and tags 
	setFamily("Mesh Processing");
	addTag("INV");
	
	// Setting the action's parameters
	// If you want to add parameters to your action, you can add them 
	// using properties
	// setProperty("PropertyName", QVariant(PropertyValue));
	

}

// --------------- destructor -------------------
InvertMesh::~InvertMesh() {
    // Do not do anything yet. 
	// Delete stuff if you create stuff 
	// (except if you use smart pointers of course !!)
}

// --------------- apply -------------------
Action::ApplyStatus InvertMesh::apply() {
    foreach (Component *comp, getTargets()) {
        MeshComponent * input = dynamic_cast<MeshComponent *> ( comp );
        process(input);
    }
    return SUCCESS;
}

void InvertMesh::process(MeshComponent * comp) {
	
	vtkSmartPointer<vtkPolyDataNormals> polydataNormals = vtkSmartPointer<vtkPolyDataNormals>::New();
	vtkSmartPointer<vtkPolyData> poly = vtkPolyData::SafeDownCast(comp->getPointSet());

	polydataNormals->SetInput(poly);
	polydataNormals->SetFlipNormals(1);
	polydataNormals->Update();

	comp->setPointSet(vtkPointSet::SafeDownCast(polydataNormals->GetOutput()));
	comp->refresh();

}

==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/sdk/actions/mesh/meshprocessing/InvertMesh.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#include "InvertMesh.h"

#include <QString>
#include <QMessageBox>
#include <QTextStream>
#include <Application.h>


#include <vtkPolyDataNormals.h>
#include <vtkSmartPointer.h>

using namespace camitk;


// --------------- Constructor -------------------
InvertMesh::InvertMesh(ActionExtension * extension) : Action(extension) {
    // Setting name, description and input component
    setName("Invert Mesh");
    setDescription("Invert the mesh faces");
    setComponent("MeshComponent");

    // Setting classification family and tags
    setFamily("Mesh Processing");
    addTag("Inside Out");
    addTag("Normal");
    addTag("Flip");
}

// --------------- destructor -------------------
InvertMesh::~InvertMesh() {
    // Do not do anything yet.
    // Delete stuff if you create stuff
    // (except if you use smart pointers of course !!)
}

// --------------- apply -------------------
Action::ApplyStatus InvertMesh::apply() {
    foreach (Component *comp, getTargets()) {
        MeshComponent * input = dynamic_cast<MeshComponent *> ( comp );
        process(input);
    }
    return SUCCESS;
}

// --------------- process -------------------
void InvertMesh::process(MeshComponent * comp) {

    vtkSmartPointer<vtkPolyDataNormals> polydataNormals = vtkSmartPointer<vtkPolyDataNormals>::New();
    vtkSmartPointer<vtkPolyData> poly = vtkPolyData::SafeDownCast(comp->getPointSet());

    polydataNormals->SetInput(poly);
    polydataNormals->SetFlipNormals(1);
    polydataNormals->Update();

    comp->setPointSet(vtkPointSet::SafeDownCast(polydataNormals->GetOutput()));
    comp->refresh();

}
